clc
clear all

%% Cross-section dimensions
%1. Outer sheath
OD_1 = 0.079; 
ID_1 = 0.067;
rm_1 = (OD_1+ID_1)/4;
t_1 = (OD_1 - ID_1)/2;

%2. Steel tubes
OD_2 = 0.016;
ID_2 = 0.012;
rm_h = (OD_2 + ID_2)/4;
t_h = (OD_2 - ID_2)/2;
n_h = 10;


%3. Inner plastic sheat
OD_3 = 0.038;
ID_3 = 0.021;
rm_3 = (OD_3 + ID_3)/4;

%4. Centre tube
OD_4 = 0.016;
ID_4=0.012;

%% Cross-section areas

A_1 = pi/4*(OD_1^2 - ID_1^2);
A_2 = pi/4*(OD_2^2 - ID_2^2);
A_3 = pi/4*(OD_3^2 - ID_3^2);
A_4 = pi/4*(OD_4^2 - ID_4^2);

t_eff = A_2/(2*pi*rm_h);
%% Moments of inertia
I_1 = pi/64*(OD_1^4 - ID_1^4);
I_2 = pi/64*(OD_2^4 - ID_2^4);
I_3 = pi/64*(OD_3^4 - ID_3^4);
I_4 = pi/64*(OD_4^4 - ID_4^4);

I_test = pi*(0.027)^3*0.0015;

alpha = 5*2*pi/360;

J_1 = pi/32*(OD_1^4 - ID_1^4);
J_2 = 2*I_2;
J_3 = pi/32*(OD_3^4 - ID_3^4);
J_4 = pi/32*(OD_4^4 - ID_4^4);

%% Material properties
E_st = 2e11;                   %E-modulus steel                  
E_os  = 3e8;                  % E-modulus outer sheat
E_in = 3e8;                % E-modulus XLPE
E_helix = 2e11;

G_st = E_st/(2*(1+0.3));
G_os = E_os/(2*(1+0.3));

%% Contact pressure
my = 0.3;
sigma_F = 20e6;

p_os = sigma_F *(t_1/(OD_1/2));

q3_1 = p_os*2*pi*rm_1*cos(alpha)/10;

beta_2c_2 = (my*(q3_1*2))/(E_st*A_2*(cos(alpha))^2*sin(alpha));

beta_2_2 = (4/pi)*beta_2c_2;

F_f1 = 1.0;
F_f2 = 0.9;

% Torsion moment
EI_e = 1000 + E_os*I_1 + I_3*E_in + 0.5*n_h*(G_st*J_2*4*sin(alpha)^2*cos(alpha)^5 + E_st*I_2*cos(alpha)^3*cos(2*alpha)^2 + E_st*I_2*cos(alpha)*(1+2*sin(alpha)^2 + sin(alpha)^4)) + 0.5*(G_st*J_2*4*sin(alpha)^2*cos(alpha)^5 + E_st*I_4*cos(alpha)^3*cos(2*alpha)^2 + E_st*I_4*cos(alpha)*(1+2*sin(alpha)^2 + sin(alpha)^4));

EI_s = 1000 + E_helix*0.5*A_2*0.027^2*F_f1*cos(alpha)^4*10;
k=0.0:0.0001:0.1;

for i = 1:length(k)
    if k(i)<=beta_2_2
        Mf_s(i) = EI_s*k(i);
    else
        Mf_s(i) = Mf_s(i-1);
    end
end

Mf_e = EI_e*k;

Mf = Mf_s + Mf_e;

for i =1:length(k)
    EI(i) = Mf(i) / k(i);
end

plot(k,Mf)
xlabel('Curvature [1/m]');
ylabel('Bending Moment [Nm]');
title('Moment-curvature relation');

ans = [Mf(349),Mf(1001)]

%% Axial stiffness
v_a = 0.3;
EA = 2*pi*rm_h*t_eff*F_f1*E_st*(cos(alpha)^2*(cos(alpha)^2 - v_a*sin(alpha)^2));

%% Torsional stiffness
GI = E_st*2*pi*rm_h^3*t_eff*F_f1*sin(alpha)^2*cos(alpha)^2;


